@@ -1,5 +1,6 @@
 #' Do a self test to verify \link{babette} that works correctly.
 #' @inheritParams default_params_doc
+#' @return Nothing. Will raise an exception if something is wrong.
 #' @author Richèl J.C. Bilderbeek
 #' @export
 #' @examples
@@ -15,7 +16,10 @@
 bbt_self_test <- function(
   beast2_options = beastier::create_beast2_options()
 ) {
-  testthat::expect_true(beastier::is_beast2_installed())
+
+  if (!beastier::is_beast2_installed()) {
+    stop("Beast2 must be installed for bbt_self_test.")
+  }
   inference_model <- beautier::create_test_inference_model()
   babette::bbt_run_from_model(
     fasta_filename = beautier::get_fasta_filename(),
